==> jc-1.4.0.tar.gz: polyglot/types/reflect/ClassPathLoader.h <==
// public class polyglot.types.reflect.ClassPathLoader

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 32257e81ded29ed1 polyglot_types_reflect_ClassPathLoader

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_types_reflect_ClassPathLoader_H_
#define _JC_polyglot_types_reflect_ClassPathLoader_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_List$object;
struct _jc_polyglot_types_reflect_ClassFile$object;
struct _jc_polyglot_types_reflect_ClassFileLoader$object;

// Typedefs
typedef struct _jc_polyglot_types_reflect_ClassPathLoader$sub_refs	_jc_polyglot_types_reflect_ClassPathLoader$sub_refs;
typedef struct _jc_polyglot_types_reflect_ClassPathLoader$sub_nonrefs	_jc_polyglot_types_reflect_ClassPathLoader$sub_nonrefs;
typedef struct _jc_polyglot_types_reflect_ClassPathLoader$refs	_jc_polyglot_types_reflect_ClassPathLoader$refs;
typedef struct _jc_polyglot_types_reflect_ClassPathLoader$nonrefs	_jc_polyglot_types_reflect_ClassPathLoader$nonrefs;
typedef struct _jc_polyglot_types_reflect_ClassPathLoader$object	_jc_polyglot_types_reflect_ClassPathLoader$object;

typedef struct _jc_polyglot_types_reflect_ClassPathLoader$fields_struct	_jc_polyglot_types_reflect_ClassPathLoader$fields_struct;
typedef const struct _jc_polyglot_types_reflect_ClassPathLoader$vmethods	_jc_polyglot_types_reflect_ClassPathLoader$vmethods;
typedef const struct _jc_polyglot_types_reflect_ClassPathLoader$vtable	_jc_polyglot_types_reflect_ClassPathLoader$vtable;
typedef const struct _jc_polyglot_types_reflect_ClassPathLoader$vtype	_jc_polyglot_types_reflect_ClassPathLoader$vtype;

// Class fields structure
struct _jc_polyglot_types_reflect_ClassPathLoader$fields_struct {
	struct _jc_object	*verbose;
};
extern _jc_polyglot_types_reflect_ClassPathLoader$fields_struct _jc_polyglot_types_reflect_ClassPathLoader$class_fields;

// Constructors
extern void _jc_polyglot_types_reflect_ClassPathLoader$method$_init$f2ee4e1d676e9c64(_jc_env *, struct _jc_polyglot_types_reflect_ClassPathLoader$object *, struct _jc_java_lang_String$object *, struct _jc_polyglot_types_reflect_ClassFileLoader$object *);
extern void _jc_polyglot_types_reflect_ClassPathLoader$method$_init$c2018ba37c205524(_jc_env *, struct _jc_polyglot_types_reflect_ClassPathLoader$object *, struct _jc_object *, struct _jc_polyglot_types_reflect_ClassFileLoader$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_polyglot_types_reflect_ClassPathLoader$method$classpath$41a069155e50d6ff(_jc_env *, struct _jc_polyglot_types_reflect_ClassPathLoader$object *);
extern struct _jc_polyglot_types_reflect_ClassFile$object *_jc_polyglot_types_reflect_ClassPathLoader$method$loadClass$88d5dad5c2f76cdd(_jc_env *, struct _jc_polyglot_types_reflect_ClassPathLoader$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_types_reflect_ClassPathLoader$method_info$classpath$41a069155e50d6ff;
extern _jc_method _jc_polyglot_types_reflect_ClassPathLoader$method_info$loadClass$88d5dad5c2f76cdd;

// Static methods
extern void _jc_polyglot_types_reflect_ClassPathLoader$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_polyglot_types_reflect_ClassPathLoader$vmethods {
	struct _jc_java_lang_String$object	*(*classpath$41a069155e50d6ff)(_jc_env *, struct _jc_polyglot_types_reflect_ClassPathLoader$object *);
	struct _jc_polyglot_types_reflect_ClassFile$object	*(*loadClass$88d5dad5c2f76cdd)(_jc_env *, struct _jc_polyglot_types_reflect_ClassPathLoader$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_polyglot_types_reflect_ClassPathLoader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_types_reflect_ClassPathLoader$vmethods	polyglot_types_reflect_ClassPathLoader;
};

// Vtype
struct _jc_polyglot_types_reflect_ClassPathLoader$vtype {
	_jc_type			type;
	_jc_polyglot_types_reflect_ClassPathLoader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_reflect_ClassPathLoader$sub_refs {
	struct _jc_object	*classpath;
	struct _jc_polyglot_types_reflect_ClassFileLoader$object	*loader;
};

// Reference instance fields (object)
struct _jc_polyglot_types_reflect_ClassPathLoader$refs {
    _jc_polyglot_types_reflect_ClassPathLoader$sub_refs	polyglot_types_reflect_ClassPathLoader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_reflect_ClassPathLoader$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_reflect_ClassPathLoader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_types_reflect_ClassPathLoader$sub_nonrefs	polyglot_types_reflect_ClassPathLoader;
};

// Object instance structure
struct _jc_polyglot_types_reflect_ClassPathLoader$object {
	_jc_polyglot_types_reflect_ClassPathLoader$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_reflect_ClassPathLoader$vtype	*vtype;
	_jc_polyglot_types_reflect_ClassPathLoader$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_reflect_ClassPathLoader$vtype _jc_polyglot_types_reflect_ClassPathLoader$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_reflect_ClassPathLoader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_reflect_ClassPathLoader$class_object;

#endif	/* _JC_polyglot_types_reflect_ClassPathLoader_H_ */

==> jc-1.4.6.tar.gz: polyglot/types/reflect/ClassPathLoader.h <==
// public class polyglot.types.reflect.ClassPathLoader

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 32257e81ded29ed1 polyglot_types_reflect_ClassPathLoader

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_types_reflect_ClassPathLoader_H_
#define _JC_polyglot_types_reflect_ClassPathLoader_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_List$object;
struct _jc_polyglot_types_reflect_ClassFile$object;
struct _jc_polyglot_types_reflect_ClassFileLoader$object;

// Typedefs
typedef struct _jc_polyglot_types_reflect_ClassPathLoader$sub_refs	_jc_polyglot_types_reflect_ClassPathLoader$sub_refs;
typedef struct _jc_polyglot_types_reflect_ClassPathLoader$sub_nonrefs	_jc_polyglot_types_reflect_ClassPathLoader$sub_nonrefs;
typedef struct _jc_polyglot_types_reflect_ClassPathLoader$refs	_jc_polyglot_types_reflect_ClassPathLoader$refs;
typedef struct _jc_polyglot_types_reflect_ClassPathLoader$nonrefs	_jc_polyglot_types_reflect_ClassPathLoader$nonrefs;
typedef struct _jc_polyglot_types_reflect_ClassPathLoader$object	_jc_polyglot_types_reflect_ClassPathLoader$object;

typedef struct _jc_polyglot_types_reflect_ClassPathLoader$fields_struct	_jc_polyglot_types_reflect_ClassPathLoader$fields_struct;
typedef const struct _jc_polyglot_types_reflect_ClassPathLoader$vmethods	_jc_polyglot_types_reflect_ClassPathLoader$vmethods;
typedef const struct _jc_polyglot_types_reflect_ClassPathLoader$vtable	_jc_polyglot_types_reflect_ClassPathLoader$vtable;
typedef const struct _jc_polyglot_types_reflect_ClassPathLoader$vtype	_jc_polyglot_types_reflect_ClassPathLoader$vtype;

// Class fields structure
struct _jc_polyglot_types_reflect_ClassPathLoader$fields_struct {
	struct _jc_object	*verbose;
};
extern _jc_polyglot_types_reflect_ClassPathLoader$fields_struct _jc_polyglot_types_reflect_ClassPathLoader$class_fields;

// Constructors
extern void _jc_polyglot_types_reflect_ClassPathLoader$method$_init$f2ee4e1d676e9c64(_jc_env *, struct _jc_polyglot_types_reflect_ClassPathLoader$object *, struct _jc_java_lang_String$object *, struct _jc_polyglot_types_reflect_ClassFileLoader$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_types_reflect_ClassPathLoader$method$_init$c2018ba37c205524(_jc_env *, struct _jc_polyglot_types_reflect_ClassPathLoader$object *, struct _jc_object *, struct _jc_polyglot_types_reflect_ClassFileLoader$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_polyglot_types_reflect_ClassPathLoader$method$classpath$41a069155e50d6ff(_jc_env *, struct _jc_polyglot_types_reflect_ClassPathLoader$object *) _JC_JCNI_ATTR;
extern struct _jc_polyglot_types_reflect_ClassFile$object *_jc_polyglot_types_reflect_ClassPathLoader$method$loadClass$88d5dad5c2f76cdd(_jc_env *, struct _jc_polyglot_types_reflect_ClassPathLoader$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_types_reflect_ClassPathLoader$method_info$classpath$41a069155e50d6ff;
extern _jc_method _jc_polyglot_types_reflect_ClassPathLoader$method_info$loadClass$88d5dad5c2f76cdd;

// Static methods
extern void _jc_polyglot_types_reflect_ClassPathLoader$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_types_reflect_ClassPathLoader$vmethods {
	struct _jc_java_lang_String$object	*(*classpath$41a069155e50d6ff)(_jc_env *, struct _jc_polyglot_types_reflect_ClassPathLoader$object *) _JC_JCNI_ATTR;
	struct _jc_polyglot_types_reflect_ClassFile$object	*(*loadClass$88d5dad5c2f76cdd)(_jc_env *, struct _jc_polyglot_types_reflect_ClassPathLoader$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_types_reflect_ClassPathLoader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_types_reflect_ClassPathLoader$vmethods	polyglot_types_reflect_ClassPathLoader;
};

// Vtype
struct _jc_polyglot_types_reflect_ClassPathLoader$vtype {
	_jc_type			type;
	_jc_polyglot_types_reflect_ClassPathLoader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_reflect_ClassPathLoader$sub_refs {
	struct _jc_object	*classpath;
	struct _jc_polyglot_types_reflect_ClassFileLoader$object	*loader;
};

// Reference instance fields (object)
struct _jc_polyglot_types_reflect_ClassPathLoader$refs {
    _jc_polyglot_types_reflect_ClassPathLoader$sub_refs	polyglot_types_reflect_ClassPathLoader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_reflect_ClassPathLoader$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_reflect_ClassPathLoader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_types_reflect_ClassPathLoader$sub_nonrefs	polyglot_types_reflect_ClassPathLoader;
};

// Object instance structure
struct _jc_polyglot_types_reflect_ClassPathLoader$object {
	_jc_polyglot_types_reflect_ClassPathLoader$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_reflect_ClassPathLoader$vtype	*vtype;
	_jc_polyglot_types_reflect_ClassPathLoader$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_reflect_ClassPathLoader$vtype _jc_polyglot_types_reflect_ClassPathLoader$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_reflect_ClassPathLoader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_reflect_ClassPathLoader$class_object;

#endif	/* _JC_polyglot_types_reflect_ClassPathLoader_H_ */
